@@ -25,10 +25,9 @@ import sys
 import optparse
 
 from . import surface
-from .surface import units
 
 
-VERSION = "0.2"
+VERSION = '0.3'
 SURFACES = {
     'SVG': surface.SVGSurface,  # Tell us if you actually use this one!
     'PNG': surface.PNGSurface,
@@ -41,7 +40,7 @@ for _output_format, _surface_type in SURFACES.items():
     _function = (
         # Two lambdas needed for the closure
         lambda surface_type: lambda *args, **kwargs:  # pylint: disable=W0108
-        surface_type.convert(*args, **kwargs))(_surface_type)
+            surface_type.convert(*args, **kwargs))(_surface_type)
     _name = 'svg2%s' % _output_format.lower()
     _function.__name__ = _name
     _function.__doc__ = surface.Surface.convert.__doc__.replace(
@@ -57,36 +56,37 @@ def main():
     option_parser.add_option(
         "-f", "--format", help="output format")
     option_parser.add_option(
-        "-d", "--dpi", help="svg resolution")
+        "-d", "--dpi", help="svg resolution", default=96)
     option_parser.add_option(
         "-o", "--output",
         default="", help="output filename")
     options, args = option_parser.parse_args()
 
-    # Set the resolution
-    if options.dpi:
-        units.DPI = float(options.dpi)
-
-    # Parse the SVG
-    output_format = (
-        options.format or
-        os.path.splitext(options.output)[1].lstrip(".") or
-        "pdf")
-
     # Print help if no argument is given
     if not args:
         option_parser.print_help()
         sys.exit()
 
-    input_ = args[0]
-    if input_ == "-":
-        # Python 2/3 hack
-        input_ = getattr(sys.stdin, "buffer", sys.stdin)
+    kwargs = {'dpi': float(options.dpi)}
 
     if not options.output or options.output == '-':
         # Python 2/3 hack
-        output = getattr(sys.stdout, "buffer", sys.stdout)
+        bytes_stdout = getattr(sys.stdout, "buffer", sys.stdout)
+        kwargs['write_to'] = bytes_stdout
     else:
-        output = options.output
+        kwargs['write_to'] = options.output
 
-    SURFACES[output_format.upper()].convert(file_obj=input_, write_to=output)
+    url = args[0]
+    if url == "-":
+        # Python 2/3 hack
+        bytes_stdin = getattr(sys.stdin, "buffer", sys.stdin)
+        kwargs['file_obj'] = bytes_stdin
+    else:
+        kwargs['url'] = url
+
+    output_format = (
+        options.format or
+        os.path.splitext(options.output)[1].lstrip(".") or
+        "pdf")
+
+    SURFACES[output_format.upper()].convert(**kwargs)
