@@ -20,10 +20,20 @@ SVG Parser.
 
 """
 
-import os
 from xml.etree import ElementTree
 from xml.parsers import expat
 
+# Python 2/3 magic imports
+# pylint: disable=E0611,F0401
+try:
+    from urllib import urlopen
+    import urlparse
+except ImportError:
+    from urllib.request import urlopen
+    from urllib import parse as urlparse  # Python 3
+# pylint: enable=E0611,F0401
+
+
 # ElementTree's API changed between 2.6 and 2.7
 # pylint: disable=C0103
 ParseError = getattr(ElementTree, 'ParseError', expat.ExpatError)
@@ -41,6 +51,15 @@ class Node(dict):
         self.tag = node.tag.split("}", 1)[-1]
         self.text = node.text
 
+        # Handle the CSS
+        style = node.attrib.get("style")
+        if style:
+            for attribute in style.split(";"):
+                if ":" in attribute:
+                    name, value = attribute.split(":", 1)
+                    node.attrib[name.strip()] = value.strip()
+            del node.attrib["style"]
+
         # Inherits from parent properties
         if parent is not None:
             items = parent.copy()
@@ -54,10 +73,12 @@ class Node(dict):
             # TODO: drop other attributes that should not be inherited
 
             self.update(items)
-            self.filename = parent.filename
+            self.url = parent.url
             self.parent = parent
 
         # TODO: manage other attributes that should be multiplicated
+        # TODO: handle opacity the right way (no transparency between plain
+        # elements in a semi-transparent parent)
         properties = dict(node.attrib.items())
         for key in properties:
             if "opacity" in key:
@@ -66,7 +87,7 @@ class Node(dict):
                         float(parent.get(key, 1.0)) * float(properties[key]))
         self.update(properties)
 
-        # manage text by creating children
+        # Manage text by creating children
         if self.tag == "text" or self.tag == "textPath":
             self.children = self.text_children(node)
 
@@ -101,22 +122,23 @@ class Tree(Node):
 
         if bytestring is not None:
             tree = ElementTree.fromstring(bytestring)
-            self.filename = None
-        elif file_obj is not None:
-            tree = ElementTree.parse(file_obj).getroot()
-            self.filename = getattr(file_obj, 'name', None)
+            self.url = None
         elif url is not None:
             if "#" in url:
                 url, element_id = url.split("#", 1)
             else:
                 element_id = None
-            if parent and parent.filename:
+            if parent and parent.url:
                 if url:
-                    url = os.path.join(os.path.dirname(parent.filename), url)
+                    url = urlparse.urljoin(parent.url, url)
                 elif element_id:
-                    url = parent.filename
-            self.filename = url
-            tree = ElementTree.parse(url).getroot()
+                    url = parent.url
+            self.url = url
+            if urlparse.urlparse(url).scheme:
+                input_ = urlopen(url)
+            else:
+                input_ = url  # filename
+            tree = ElementTree.parse(input_).getroot()
             if element_id:
                 iterator = (
                     tree.iter() if hasattr(tree, 'iter')
@@ -125,6 +147,9 @@ class Tree(Node):
                     if element.get("id") == element_id:
                         tree = element
                         break
+        elif file_obj is not None:
+            tree = ElementTree.parse(file_obj).getroot()
+            self.url = getattr(file_obj, 'name', url)
         else:
             raise TypeError(
                 'No input. Use one of bytestring, file_obj or url.')
